pub enum Repeatability {
High,
Medium,
Low,
}Expand description
The repeatability influences the measument duration and the energy consumption of the sensor It also gives a more or less accurate measurement
Here are the repeatibility values for humidity and temperature:
- Low repeatability: 0.21 %RH - 0.15 °C
- Medium repeatability: 0.15 %RH - 0.08 °C
- High repeatability: 0.08 %RH - 0.04 °C
The measurement durations are the following:
- Low repeatability: 4 ms (with supply voltage of 2.4-5.5 V) or 4.5 ms (with supply voltage of 2.15-2.4 V)
- Medium repeatability: 6 ms (with supply voltage of 2.4-5.5 V) or 6.5 ms (with supply voltage of 2.15-2.4 V)
- High repeatability: 15 ms (with supply voltage of 2.4-5.5 V) or 15.5 ms (with supply voltage of 2.15-2.4 V)
Variants
High
High repeatability: 0.08 %RH - 0.04 °C
Medium
Medium repeatability: 0.15 %RH - 0.08 °C
Low
Low repeatability: 0.21 %RH - 0.15 °C